@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# Build script for cross compiling and packaging SQLite 3
+# Build script for cross compiling and packaging SQLite
 # ODBC drivers and tools for Win32 using MinGW and NSIS.
 # Tested on Fedora Core 3/5/8, Debian Etch, RHEL 5/6.
 #
@@ -23,8 +23,8 @@
 set -e
 
 VER2=2.8.17
-VER3=3.32.3
-VER3X=3320300
+VER3=3.43.0
+VER3X=3430000
 VERZ=1.2.8
 
 nov2=false
@@ -261,7 +261,7 @@ echo "====================="
 echo "Preparing sqlite3 ..."
 echo "====================="
 test -r sqlite-src-${VER3X}.zip || \
-    wget -c http://www.sqlite.org/2020/sqlite-src-${VER3X}.zip \
+    wget -c http://www.sqlite.org/2023/sqlite-src-${VER3X}.zip \
       --no-check-certificate
 test -r sqlite-src-${VER3X}.zip || exit 1
 test -r extension-functions.c ||
@@ -305,8 +305,10 @@ EOD
 
 test -r sqlite3/tool/mkshellc.tcl && \
   sed -i -e 's/ rb/ r/g' sqlite3/tool/mkshellc.tcl
+
 # appendText name clash in sqlite3 shell
-test "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" \
+test "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" -o "$VER3" = "3.42.0" \
+  -o "$VER3" = "3.43.0" \
   && perl -pi -e 's/appendText/shAppendText/g' sqlite3/src/shell.c.in
 
 test -r sqlite3/src/shell.c.in &&
@@ -404,6 +406,7 @@ test "$VER3" != "3.7.14" -a "$VER3" != "3.7.14.1" -a "$VER3" != "3.7.15" \
   -a "$VER3" != "3.14.0" -a "$VER3" != "3.14.1" -a "$VER3" != "3.15.0" \
   -a "$VER3" != "3.15.1" -a "$VER3" != "3.15.2" -a "$VER3" != "3.19.3" \
   -a "$VER3" != "3.22.0" -a "$VER3" != "3.32.2" -a "$VER3" != "3.32.3" \
+  -a "$VER3" != "3.42.0" -a "$VER3" != "3.43.0" \
   && patch sqlite3/src/libshell.c <<'EOD'
 --- sqlite3.orig/src/libshell.c  2007-01-08 23:40:05.000000000 +0100
 +++ sqlite3/src/libshell.c  2007-01-10 18:35:43.000000000 +0100
@@ -587,6 +590,7 @@ test "$VER3" = "3.8.9" -o "$VER3" = "3.8.10" -o "$VER3" = "3.8.11" \
 EOD
 
 test "$VER3" = "3.22.0" -o "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" \
+  -o "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" \
   && patch sqlite3/src/os_win.h <<'EOD'
 --- sqlite3.orig/src/os_win.h       2018-01-22 19:57:25.000000000 +0100
 +++ sqlite3/src/os_win.h    2018-02-21 21:13:46.000000000 +0100
@@ -666,9 +670,25 @@ test "$VER3" = "3.13.0" -o "$VER3" = "3.14.0" -o "$VER3" = "3.14.1" \
      warnInmemoryDb = argc==1;
 EOD
 
+test "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" \
+  && rm -f sqlite3/src/libshell.c && patch sqlite3/src/libshell.c <<'EOD'
+--- /dev/null	2023-08-23 14:06:59.000000000 +0200
++++ sqlite3/src/libshell.c	2023-08-23 14:06:59.00000000 +0200
+@@ -0,0 +1,7 @@
++#include <stdio.h>
++ 
++int sqlite3_main(int argc, char **argv)
++{
++  fprintf(stderr, "not supported anymore\n");
++  return 1;
++}
+EOD 
+
 rm -f sqlite3/src/minshell.c
 touch sqlite3/src/minshell.c
-patch sqlite3/src/minshell.c <<'EOD'
+
+test "$VER3" != "3.42.0" -a "$VER3" != "3.43.0" \
+  && patch sqlite3/src/minshell.c <<'EOD'
 --- sqlite3.orig/src/minshell.c  2007-01-10 18:46:47.000000000 +0100
 +++ sqlite3/src/minshell.c  2007-01-10 18:46:47.000000000 +0100
 @@ -0,0 +1,20 @@
@@ -694,6 +714,48 @@ patch sqlite3/src/minshell.c <<'EOD'
 +}
 EOD
 
+test "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" \
+  && cp -p sqlite3/src/shell.c sqlite3/src/minshell.c \
+  && patch -d sqlite3 -p1 <<'EOD'
+--- sqlite3.orig/src/minshell.c	2023-08-24 21:58:36.000000000 +0200
++++ sqlite3/src/minshell.c	2023-08-25 16:11:55.290287100 +0200
+@@ -128,6 +129,10 @@
+ #include <ctype.h>
+ #include <stdarg.h>
+ 
++#ifdef _WIN32
++#include <windows.h>
++#endif
++
+ #if !defined(_WIN32) && !defined(WIN32)
+ # include <signal.h>
+ # if !defined(__RTP__) && !defined(_WRS_KERNEL) && !defined(SQLITE_WASI)
+@@ -28154,6 +28158,23 @@
+     }
+   }
+ 
++#if defined(_WIN32) && !defined(__TINYC__)
++  if( data.pAuxDb->zDbFilename==0 ){
++    static OPENFILENAMEW ofn;
++    static WCHAR wDbFn[1024];
++    static char zDbFn[4096];
++    ofn.lStructSize = sizeof(ofn);
++    ofn.lpstrFile = (LPTSTR) wDbFn;
++    ofn.nMaxFile = sizeof(wDbFn);
++    ofn.Flags = OFN_PATHMUSTEXIST | OFN_EXPLORER | OFN_NOCHANGEDIR;
++    if( GetOpenFileNameW(&ofn) ){
++      WideCharToMultiByte(CP_UTF8, 0, wDbFn, -1, zDbFn, sizeof(zDbFn),
++                          NULL, NULL);
++      data.pAuxDb->zDbFilename = zDbFn;
++    }
++  }
++#endif
++
+   if( data.pAuxDb->zDbFilename==0 ){
+ #ifndef SQLITE_OMIT_MEMORYDB
+     data.pAuxDb->zDbFilename = ":memory:";
+EOD
+
 # amalgamation: add libshell.c 
 test "$VER3" != "3.5.6" && test -r sqlite3/tool/mksqlite3c.tcl && \
   patch -d sqlite3 -p1 <<'EOD'
@@ -746,6 +808,7 @@ test "$VER3" != "3.6.15" -a "$VER3" != "3.6.16" -a "$VER3" != "3.6.17" \
   -a "$VER3" != "3.14.0" -a "$VER3" != "3.14.1" -a "$VER3" != "3.15.0" \
   -a "$VER3" != "3.15.1" -a "$VER3" != "3.15.2" -a "$VER3" != "3.19.3" \
   -a "$VER3" != "3.22.0" -a "$VER3" != "3.32.2" -a "$VER3" != "3.32.3" \
+  -a "$VER3" != "3.42.0" -a "$VER3" != "3.43.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 diff -u sqlite3.orig/src/build.c sqlite3/src/build.c
 --- sqlite3.orig/src/build.c	2007-01-09 14:53:04.000000000 +0100
@@ -810,14 +873,15 @@ test "$VER3" != "3.8.8" -a "$VER3" != "3.8.9" -a "$VER3" != "3.8.10" \
   -a "$VER3" != "3.12.2" -a "$VER3" != "3.13.0" -a "$VER3" != "3.14.0" \
   -a "$VER3" != "3.14.1" -a "$VER3" != "3.15.0" -a "$VER3" != "3.15.1" \
   -a "$VER3" != "3.15.2" -a "$VER3" != "3.19.3" -a "$VER3" != "3.22.0" \
-  -a "$VER3" != "3.32.2" -a "$VER3" != "3.32.3" \
+  -a "$VER3" != "3.32.2" -a "$VER3" != "3.32.3" -a "$VER3" != "3.42.0" \
+  -a "$VER3" != "3.43.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 diff -u sqlite3.orig/src/tclsqlite.c sqlite3/src/tclsqlite.c
 --- sqlite3.orig/src/tclsqlite.c	2007-04-06 17:02:14.000000000 +0200
 +++ sqlite3/src/tclsqlite.c	2007-04-10 07:47:49.000000000 +0200
 @@ -14,6 +14,7 @@
  **
- ** $Id: mingw64-cross-build.sh,v 1.69 2020/06/20 11:55:37 chw Exp chw $
+ ** $Id: mingw64-cross-build.sh,v 1.72 2023/08/25 15:11:06 chw Exp chw $
  */
 +#ifndef NO_TCL     /* Omit this whole file if TCL is unavailable */
  #include "tcl.h"
@@ -837,7 +901,8 @@ test "$VER3" = "3.8.8" -o "$VER3" = "3.8.9" -o "$VER3" = "3.8.10" \
   -o "$VER3" = "3.12.2" -o "$VER3" = "3.13.0" -o "$VER3" = "3.14.0" \
   -o "$VER3" = "3.14.1" -o "$VER3" = "3.15.0" -o "$VER3" = "3.15.1" \
   -o "$VER3" = "3.15.2" -o "$VER3" = "3.19.3" -o "$VER3" = "3.22.0" \
-  -o "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" \
+  -o "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" -o "$VER3" = "3.42.0" \
+  -o "$VER3" = "3.43.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/src/tclsqlite.c    2015-01-16 14:47:26.000000000 +0100
 +++ sqlite3/src/tclsqlite.c 2015-01-19 17:56:26.517386413 +0100
@@ -1011,6 +1076,7 @@ test "$VER3" != "3.6.21" -a "$VER3" != "3.6.22" -a "$VER3" != "3.6.23" \
   -a "$VER3" != "3.14.0" -a "$VER3" != "3.14.1" -a "$VER3" != "3.15.0" \
   -a "$VER3" != "3.15.1" -a "$VER3" != "3.15.2" -a "$VER3" != "3.19.3" \
   -a "$VER3" != "3.22.0" -a "$VER3" != "3.32.2" -a "$VER3" != "3.32.3" \
+  -a "$VER3" != "3.42.0" -a "$VER3" != "3.43.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c 2008-02-02 17:24:34.000000000 +0100
 +++ sqlite3/ext/fts3/fts3.c      2008-03-16 11:29:02.000000000 +0100
@@ -1162,7 +1228,7 @@ test "$VER3" != "3.7.8" -a "$VER3" != "3.7.9" -a "$VER3" != "3.7.10" \
   -a "$VER3" != "3.13.0" -a "$VER3" != "3.14.0" -a "$VER3" != "3.14.1" \
   -a "$VER3" != "3.15.0" -a "$VER3" != "3.15.1" -a "$VER3" != "3.15.2" \
   -a "$VER3" != "3.19.3" -a "$VER3" != "3.22.0" -a "$VER3" != "3.32.2" \
-  -a "$VER3" != "3.32.3" \
+  -a "$VER3" != "3.32.3" -a "$VER3" != "3.42.0" -a "$VER3" != "3.43.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_hash.c    2007-11-24 01:41:52.000000000 +0100
 +++ sqlite3/ext/fts3/fts3_hash.c 2008-03-16 11:39:57.000000000 +0100
@@ -1512,6 +1578,7 @@ test "$VER3" != "3.8.0" -a "$VER3" != "3.8.1" -a "$VER3" != "3.8.2" \
   -a "$VER3" != "3.14.0" -a "$VER3" != "3.14.1" -a "$VER3" != "3.15.0" \
   -a "$VER3" != "3.15.1" -a "$VER3" != "3.15.2" -a "$VER3" != "3.19.3" \
   -a "$VER3" != "3.22.0" -a "$VER3" != "3.32.2" -a "$VER3" != "3.32.3" \
+  -a "$VER3" != "3.42.0" -a "$VER3" != "3.43.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/rtree/rtree.c	2008-07-16 16:43:35.000000000 +0200
 +++ sqlite3/ext/rtree/rtree.c	2008-07-17 08:59:53.000000000 +0200
@@ -1560,7 +1627,8 @@ test "$VER3" = "3.7.3" -o "$VER3" = "3.7.4" -o "$VER3" = "3.7.5" \
 EOD
 
 # patch: fix rtree to be loadable as extension module
-test "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" \
+test "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" -o "$VER3" = "3.42.0" \
+  -o "$VER3" = "3.43.0" \
   && perl -pi -e 's/sqlite3_rtree_init/sqlite3_extension_init/g' \
     sqlite3/ext/rtree/rtree.c
 
@@ -1600,6 +1668,7 @@ test "$VER3" = "3.7.7" -o "$VER3" = "3.7.7.1" -o "$VER3" = "3.7.8" \
   -o "$VER3" = "3.14.0" -o "$VER3" = "3.14.1" -o "$VER3" = "3.15.0" \
   -o "$VER3" = "3.15.1" -o "$VER3" = "3.15.2" -o "$VER3" = "3.19.3" \
   -o "$VER3" = "3.22.0" -o "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" \
+  -o "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_aux.c	2011-06-24 09:06:08.000000000 +0200
 +++ sqlite3/ext/fts3/fts3_aux.c	2011-06-25 06:44:08.000000000 +0200
@@ -1655,7 +1724,7 @@ test "$VER3" = "3.7.8" -o "$VER3" = "3.7.9" -o "$VER3" = "3.7.10" \
   -o "$VER3" = "3.13.0" -o "$VER3" = "3.14.0" -o "$VER3" = "3.14.1" \
   -o "$VER3" = "3.15.0" -o "$VER3" = "3.15.1" -o "$VER3" = "3.15.2" \
   -o "$VER3" = "3.19.3" -o "$VER3" = "3.22.0" -o "$VER3" = "3.32.2" \
-  -o "$VER3" = "3.32.3" \
+  -o "$VER3" = "3.32.3" -o "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c	2011-09-19 20:46:52.000000000 +0200
 +++ sqlite3/ext/fts3/fts3.c	2011-09-20 09:47:40.000000000 +0200
@@ -1696,6 +1765,7 @@ test "$VER3" = "3.7.7" -o "$VER3" = "3.7.7.1" -o "$VER3" = "3.7.8" \
   -o "$VER3" = "3.14.0" -o "$VER3" = "3.14.1" -o "$VER3" = "3.15.0" \
   -o "$VER3" = "3.15.1" -o "$VER3" = "3.15.2" -o "$VER3" = "3.19.3" \
   -o "$VER3" = "3.22.0" -o "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" \
+  -o "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_expr.c	2011-06-24 09:06:08.000000000 +0200
 +++ sqlite3/ext/fts3/fts3_expr.c	2011-06-25 06:47:00.000000000 +0200
@@ -1876,7 +1946,8 @@ test "$VER3" = "3.8.0" -o "$VER3" = "3.8.1" -o "$VER3" = "3.8.2" \
          zAltEntry[iEntry++] = (char)sqlite3UpperToLower[(unsigned)c];
 EOD
 
-test "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" \
+test "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" -o "$VER3" = "3.42.0" \
+  -o "$VER3" = "3.43.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/src/loadext.c	2020-06-04 16:01:10.000000000 +0200
 +++ sqlite3/src/loadext.c	2020-06-12 05:47:05.000000000 +0200
@@ -1902,7 +1973,7 @@ test "$VER3" = "3.8.2" -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" \
   -o "$VER3" = "3.13.0" -o "$VER3" = "3.14.0" -o "$VER3" = "3.14.1" \
   -o "$VER3" = "3.15.0" -o "$VER3" = "3.15.1" -o "$VER3" = "3.15.2" \
   -o "$VER3" = "3.19.3" -o "$VER3" = "3.22.0" -o "$VER3" = "3.32.2" \
-  -o "$VER3" = "3.32.3" \
+  -o "$VER3" = "3.32.3" -o "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c      2014-03-26 10:26:28.000000000 +0100
 +++ sqlite3/ext/fts3/fts3.c  2014-03-26 16:54:39.000000000 +0100
@@ -1925,6 +1996,7 @@ test "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" -o "$VER3" = "3.8.9" \
   -o "$VER3" = "3.14.0" -o "$VER3" = "3.14.1" -o "$VER3" = "3.15.0" \
   -o "$VER3" = "3.15.1" -o "$VER3" = "3.15.2" -o "$VER3" = "3.19.3" \
   -o "$VER3" = "3.22.0" -o "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" \
+  -o "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/src/threads.c      2014-10-17 13:38:27.000000000 +0200
 +++ sqlite3/src/threads.c   2014-10-26 13:40:26.000000000 +0100
@@ -1967,7 +2039,8 @@ test "$VER3" = "3.10.0" -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" \
   -o "$VER3" = "3.19.3" -o "$VER3" = "3.22.0" \
   && perl -pi -e 's/ rb\]/ r\]/g' sqlite3/tool/mkopcodec.tcl \
       sqlite3/tool/tostr.tcl sqlite3/tool/addopcodes.tcl
-test "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" \
+test "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" -o "$VER3" = "3.42.0" \
+  -o "$VER3" = "3.43.0" \
   && perl -pi -e 's/ rb\]/ r\]/g' sqlite3/tool/mkopcodec.tcl \
       sqlite3/tool/mkccode.tcl
 
@@ -2078,7 +2151,8 @@ test "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" \
  #   define access(f,m) _access((f),(m))
 EOD
 # rtree using internal core func
-test "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" \
+test "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" -o "$VER3" = "3.42.0" \
+  -o "$VER3" = "3.43.0" \
   && patch sqlite3/ext/rtree/rtree.c <<'EOD'
 --- rtree.c.orig	2020-06-04 16:01:10.000000000 +0200
 +++ rtree.c	2020-06-12 11:51:49.000000000 +0200
